﻿using System.Windows;
using System.Windows.Controls;

namespace CollectionBinding
{
    public partial class MainPage : UserControl
    {
        CompanyViewModel c = new CompanyViewModel();

        public MainPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {

            //伪造一些数据，测试绑定
            Employee e1 = new Employee() { Name = "张三", Salary = 3000 };
            Employee e2 = new Employee() { Name = "李四", Salary = 4000 };
            Employee e3 = new Employee() { Name = "杨过", Salary = 9999 };
            c.EmployeeCollection.Add(e1);
            c.EmployeeCollection.Add(e2);
            c.EmployeeCollection.Add(e3);

            EmployeePrizeViewModel p1 = new EmployeePrizeViewModel() { Employees = c.EmployeeCollection, EmployeePrize = new EmployeePrize() { EmployeeName = "杨过", PrizeName = "玄铁剑" } };
            EmployeePrizeViewModel p2 = new EmployeePrizeViewModel() { Employees = c.EmployeeCollection, EmployeePrize = new EmployeePrize() { EmployeeName = "李四", PrizeName = "ThinkPad X220" } };
            c.EmployeePrizeViewModelCollection.Add(p1);
            c.EmployeePrizeViewModelCollection.Add(p2);

            this.DataContext = c;

        }


        /// <summary>
        /// 删除员工
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void RemoveEmployee(object sender, RoutedEventArgs e)
        {
            var emp = (sender as Button).DataContext as Employee;
            if (emp != null) { c.EmployeeCollection.Remove(emp); }
        }


        /// <summary>
        /// 添加员工
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void AddEmployee(object sender, RoutedEventArgs e)
        {
            c.EmployeeCollection.Add(new Employee() { Name = "新人", Salary = 1000 });
        }

        /// <summary>
        /// 增加中奖名单
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void AddEmployeePrize(object sender, RoutedEventArgs e)
        {
            var empPrizeViewModel = new EmployeePrizeViewModel() { Employees = c.EmployeeCollection };            
            var empPrize = new EmployeePrize();
            if (c.EmployeeCollection.Count > 0) 
            {
                empPrize.EmployeeName = c.EmployeeCollection[c.EmployeeCollection.Count - 1].Name;
            }
            empPrizeViewModel.EmployeePrize = empPrize;

            c.EmployeePrizeViewModelCollection.Add(empPrizeViewModel);
        }

        /// <summary>
        /// 删除中奖名单
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void RemoveEmployeePrize(object sender, RoutedEventArgs e)
        {
            var empPrizeViewModel = (sender as Button).DataContext as EmployeePrizeViewModel;
            if (empPrizeViewModel != null) { c.EmployeePrizeViewModelCollection.Remove(empPrizeViewModel); }
        }

        private void ShowCompanyViewModel(object sender, RoutedEventArgs e)
        {
            //如果员工列表有名字修改，这里先同步一下
            foreach (var item in c.EmployeePrizeViewModelCollection)
            {
                item.EmployeePrize.EmployeeName = item.Employees[item.SelectedIndex].Name;
            }

            this.textBox1.Text = c.ToString();
        }

        private void ComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            var combox = (sender) as ComboBox;
            if (combox.SelectedIndex != -1) 
            {
                (combox.DataContext as EmployeePrizeViewModel).SelectedIndex = combox.SelectedIndex;
            }
        }


    }
}
