﻿using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Xml.Serialization;


namespace CollectionBinding
{
    public class CompanyViewModel : NotifyPropertyChangedObject
    {

        private ObservableCollection<Employee> _employeeCollection = new ObservableCollection<Employee>();

        /// <summary>
        /// 公司的"员工集合"
        /// </summary>
        public ObservableCollection<Employee> EmployeeCollection
        {
            get { return _employeeCollection; }

        }

        private ObservableCollection<EmployeePrizeViewModel> _employeePrizeViewModelCollection = new ObservableCollection<EmployeePrizeViewModel>();

        /// <summary>
        /// 中奖名单
        /// </summary>
        public ObservableCollection<EmployeePrizeViewModel> EmployeePrizeViewModelCollection
        {
            get { return _employeePrizeViewModelCollection; }
            
        }

        /// <summary>
        /// 构造函数
        /// </summary>
        public CompanyViewModel()
        {
            _employeeCollection.CollectionChanged += new NotifyCollectionChangedEventHandler(_employeeCollection_CollectionChanged);
        }

        /// <summary>
        /// 员工有“增减”时自动触发
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void _employeeCollection_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            //重新计算工资总和
            computeSalaryTotal();

            //每个员工的“工资”属性变化时，自动触发指定事件
            foreach (var item in _employeeCollection)
            {

                item.PropertyChanged -= new PropertyChangedEventHandler(item_PropertyChanged);
                item.PropertyChanged += new PropertyChangedEventHandler(item_PropertyChanged);

            }
        }

        /// <summary>
        /// 员工属性变化时自动调用本方法
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void item_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            //如果是"工资"属性变化，则自动重新计算工资汇总
            if (e.PropertyName == "Salary")
            {
                computeSalaryTotal();
            }
        }

        private void computeSalaryTotal()
        {
            _salaryTotal = _employeeCollection.Sum(c => c.Salary);
            OnPropertyChanged("SalaryTotal");//工资总合重新计算后，向外广播事件，以便UI能自动更新
        }

        private int _salaryTotal = 0;

        /// <summary>
        /// 工资汇总
        /// </summary>
        public int SalaryTotal
        {
            get
            {
                return _salaryTotal;
            }
        }

        public override string ToString()
        {
            string result = "";
            XmlSerializer xmlSerializer = new XmlSerializer(typeof(CompanyViewModel));
            using (MemoryStream ms = new MemoryStream())
            {
                try
                {
                    xmlSerializer.Serialize(ms, this);
                    result = Encoding.UTF8.GetString(ms.ToArray(), 0, (int)ms.Length);
                }
                catch { }
            }
            return result;

        }
    }



}
